RawError

Enum RawError 

#[repr(u32)]
pub enum RawError {
Show 49 variants Success = 0, Unknown = 4_294_967_295, SvcHandlerMissing = 1, SoftdeviceNotEnabled = 2, Internal = 3, NoMem = 4, NotFound = 5, NotSupported = 6, InvalidParam = 7, InvalidState = 8, InvalidLength = 9, InvalidFlags = 10, InvalidData = 11, DataSize = 12, Timeout = 13, Null = 14, Forbidden = 15, InvalidAddr = 16, Busy = 17, ConnCount = 18, Resources = 19, SdmLfclkSourceUnknown = 4_096, SdmIncorrectInterruptConfiguration = 4_097, SdmIncorrectClenr0 = 4_098, SocMutexAlreadyTaken = 8_192, SocNvicInterruptNotAvailable = 8_193, SocNvicInterruptPriorityNotAllowed = 8_194, SocNvicShouldNotReturn = 8_195, SocPowerModeUnknown = 8_196, SocPowerPofThresholdUnknown = 8_197, SocPowerOffShouldNotReturn = 8_198, SocRandNotEnoughValues = 8_199, SocPpiInvalidChannel = 8_200, SocPpiInvalidGroup = 8_201, BleNotEnabled = 12_289, BleInvalidConnHandle = 12_290, BleInvalidAttrHandle = 12_291, BleInvalidAdvHandle = 12_292, BleInvalidRole = 12_293, BleBlockedByOtherLinks = 12_294, BleGapUuidListMismatch = 12_800, BleGapDiscoverableWithWhitelist = 12_801, BleGapInvalidBleAddr = 12_802, BleGapWhitelistInUse = 12_803, BleGapDeviceIdentitiesInUse = 12_804, BleGapDeviceIdentitiesDuplicate = 12_805, BleGattcProcNotPermitted = 13_056, BleGattsInvalidAttrType = 13_312, BleGattsSysAttrMissing = 13_313,
}
All possible errors returned by softdevice calls.

Variants



Success = 0

This is not really an error, but is added here anyway, just in case someone mistakenly converts NRF_SUCCESS into RawError.



Unknown = 4_294_967_295



SvcHandlerMissing = 1



SoftdeviceNotEnabled = 2



Internal = 3



NoMem = 4



NotFound = 5



NotSupported = 6



InvalidParam = 7



InvalidState = 8



InvalidLength = 9



InvalidFlags = 10



InvalidData = 11



DataSize = 12



Timeout = 13



Null = 14



Forbidden = 15



InvalidAddr = 16



Busy = 17



ConnCount = 18



Resources = 19



SdmLfclkSourceUnknown = 4_096



SdmIncorrectInterruptConfiguration = 4_097



SdmIncorrectClenr0 = 4_098



SocMutexAlreadyTaken = 8_192



SocNvicInterruptNotAvailable = 8_193



SocNvicInterruptPriorityNotAllowed = 8_194



SocNvicShouldNotReturn = 8_195



SocPowerModeUnknown = 8_196



SocPowerPofThresholdUnknown = 8_197



SocPowerOffShouldNotReturn = 8_198



SocRandNotEnoughValues = 8_199



SocPpiInvalidChannel = 8_200



SocPpiInvalidGroup = 8_201



BleNotEnabled = 12_289



BleInvalidConnHandle = 12_290



BleInvalidAttrHandle = 12_291



BleInvalidAdvHandle = 12_292



BleInvalidRole = 12_293



BleGapUuidListMismatch = 12_800



BleGapDiscoverableWithWhitelist = 12_801



BleGapInvalidBleAddr = 12_802



BleGapWhitelistInUse = 12_803



BleGapDeviceIdentitiesInUse = 12_804



BleGapDeviceIdentitiesDuplicate = 12_805



BleGattcProcNotPermitted = 13_056



BleGattsInvalidAttrType = 13_312



BleGattsSysAttrMissing = 13_313

Implementations